@@ -2,5 +2,6 @@ define([
   './routes/overview-states',
   './routes/settings-states',
   './routes/management-states',
-  './routes/agents-states'
-], function() {})
+  './routes/agents-states',
+  './routes/security-states',
+], function () {})
