@@ -25,5 +25,14 @@ define([
   './restartService/restartService',
   './checkDaemons/checkDaemonsService',
   './app-version/appVersionService',
-  './sourceTypeStorageService/sourceTypeStorageService'
-], function() {})
+  './sourceTypeStorageService/sourceTypeStorageService',
+  './splunk-services/splunk-users',
+  './validationService/validationService',
+  './requirementService/requirementService',
+  './security_services/actions_enum',
+  './security_services/security_service',
+  './security/rule/ruleService',
+  './security/role/roleService',
+  './security/policy/policyService',
+  './security/user/userService',
+], function () {})
